AsyncRobot

Trait AsyncRobot 

pub trait AsyncRobot {
    // Provided methods
    fn opcontrol(&mut self) -> impl Future<Output = Result> { ... }
    fn auto(&mut self) -> impl Future<Output = Result> { ... }
    fn disabled(&mut self) -> impl Future<Output = Result> { ... }
    fn comp_init(&mut self) -> impl Future<Output = Result> { ... }
}
A trait for robot code that spins up the pros-rs async executor. This is the preferred trait to run robot code.

Provided Methods

fn opcontrol(&mut self) -> impl Future<Output = Result>

Runs during the operator control period. This function may be called more than once. For that reason, do not use Peripherals::takein this function.

fn auto(&mut self) -> impl Future<Output = Result>

Runs during the autonomous period.

fn disabled(&mut self) -> impl Future<Output = Result>

Runs continuously during the disabled period.

fn comp_init(&mut self) -> impl Future<Output = Result>

Runs once when the competition system is initialized.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors